"""
Provide RFC 7807-compliant problem details responses for the API.
"""

from typing import Optional


def unauthorized():
    """
    Return a 401 message and status code
    """
    return _problem_response(title="Unauthorized", status=401)


def not_found():
    """
    Return a 404 message and status code
    """
    return _problem_response(title="Not Found", status=404)


def _problem_response(
    title: str,
    status: int,
    type_uri: Optional[str] = None,
    extensions: Optional[dict] = None,
) -> tuple[dict, int, dict]:
    type_dict = {"type": type_uri} if type_uri is not None else {}
    title_dict = {"title": title}

    # Combine the type_dict, title_dict and extensions (if provided) into one response dictionary
    response_dict = type_dict | title_dict | (extensions or {})

    return (
        response_dict,
        status,
        {"Content-Type": "application/problem+json"},
    )
